******************************************************************************
* Gross Capital Flows: Dynamics and Crises
* F. Broner, T. Didier, A. Erce and S. Schmukler 
* Journal of Monetary Economics 60(1), 113-133
******************************************************************************
clear all
capture log close
set more off

******************************************************************************
*** Loading the Database
******************************************************************************
local inputfolder "E:\UPDATE\KFlows\JME\DATA\Public Files\"
cd "`inputfolder'"
use "`inputfolder'\BDES_JME2013-DATASET.dta", clear

capture mkdir BDES_MainTables
cd BDES_MainTables

tsset cnum year

******************************************************************************
*** Main Variables in the Paper
*** Flows are normalized by trend GDP 
******************************************************************************
/*

gen cif = fdi_l+pi_l+oi_l
gen cod = fdi_a+pi_a+oi_a+rsrv
gen net = cif - cod
gen tot = cif + cod

gen CIF = ((fdi_l+pi_l+oi_l)/hp_ngdp)*100
gen COD = ((fdi_a+pi_a+oi_a+rsrv)/hp_ngdp)*100
gen NET = CIF - COD
gen TOT = CIF + COD

gen PIA = (pi_a/hp_ngdp)*100
gen OIA =(oi_a/hp_ngdp)*100
gen RES = (rsrv/hp_ngdp)*100
gen FDIA = (fdi_a/hp_ngdp)*100
gen PIL = (pi_l/hp_ngdp)*100
gen OIL =(oi_l/hp_ngdp)*100
gen FDIL = (fdi_l/hp_ngdp)*100
gen PIAe = (pi_a_eq/hp_ngdp)*100
gen PIAd = (pi_a_db/hp_ngdp)*100
gen PILe = (pi_l_eq/hp_ngdp)*100
gen PILd = (pi_l_db/hp_ngdp)*100
gen TB = (tb_gs/hp_ngdp)*100

*/
******************************************************************************
*** Auxiliary and Standardized Variables 
******************************************************************************

*** Relevant Dummies ***

* In earlier versions of the paper, we noted a break in the series for Libya.
* To take such a break into account, we decided to use two country-trends for Libya. 
* The results presented in the paper are robust if only on country-trend is used.

qui sum cnum
replace cnum=`=r(max)+1' if cname=="Libya" & year<1996

sort cname year
qui: tab cnum, gen(t)
qui tab cnum
local i = 1
quietly while `i'  <=`r(r)'  {
replace t`i' = t`i'[_n-1]+1 if year != 1970 &  t`i'==1
replace t`i' = . if year == 1968
replace t`i' = . if year == 1969
replace t`i' = . if year == 2010
replace t`i' = . if year == 2011
local i = `i' + 1
}

qui sum cnum if cname=="Libya"
replace cnum=`r(min)' if cname=="Libya"
qui: tab cnum, gen(ct)
qui: tab year, gen(y)

*** STANDARDIZING THESE VARIABLES ***

gen not_sdCOD=COD
gen not_sdCIF=CIF
gen not_sdNET=NET
gen not_sdTOT=TOT

gen not_sdTB=TB
gen not_sdPIA=PIA
gen not_sdOIA=OIA
gen not_sdRES=RES
gen not_sdFDIA=FDIA
gen not_sdPIL=PIL
gen not_sdOIL=OIL
gen not_sdFDIL=FDIL
gen not_sdPIAe=PIAe
gen not_sdPIAd=PIAd
gen not_sdPILe=PILe
gen not_sdPILd=PILd

sort cnum year
quietly foreach j of varlist PIA OIA RES FDIA PIL OIL FDIL PIAe PIAd PILe PILd CIF COD NET TOT TB{
	gen `j'sd=.
	gen `j'mean=.
	qui tab cnum
	local i = 1
	while `i'  <= `r(r)' {
		qui: sum `j' if ct`i'==1
		replace `j'sd=r(sd) if ct`i'==1
		replace `j'mean=r(mean) if ct`i'==1
		replace `j'=(`j'-r(mean))/r(sd) if ct`i'==1
		replace `j'=0 if not_sd`j'==0 & `j'==. //replacing back with 0s when all obs in a country are 0
		local i = `i' + 1
		qui tab cnum
	}
}

quietly foreach j of varlist PIA OIA RES FDIA PIL OIL FDIL PIAe PIAd PILe PILd TB{
	drop not_sd`j'
	}

******************************************************************************
******************************************************************************
*	TABLES SECTION			
******************************************************************************
******************************************************************************

qui tab year if year>1969 & year<2010
local maxyeardummy = `r(r)'
qui tab cnum
local maxcountrydummy = `r(r)'

** Settings **
local countrydummies // "ct1-ct`maxcountrydummy'"
local countrytrenddummies "t1-t`maxcountrydummy'"
				
*************
* Table 1
* Capital Flows: Summary Statistics
*************
quietly foreach j of varlist not_sdCIF not_sdCOD not_sdNET not_sdTOT {

gen `j'_70 = `j' if year < 1980
gen `j'_80 = `j' if year < 1990 & year > 1979
gen `j'_90 = `j' if year < 2000 & year > 1989
gen `j'_00 = `j' if year > 1999 & year < .

	gen `j'_allmean= .
	gen `j'_70mean = .
	gen `j'_80mean = .
	gen `j'_90mean = .
	gen `j'_00mean = .
	gen `j'_allsd= .
	gen `j'_70sd = .
	gen `j'_80sd = .
	gen `j'_90sd = .
	gen `j'_00sd = .

	qui tab cnum
	local maxc = r(r)
	local i = 1
	while `i'  <= `maxc' {
		qui sum `j' if ct`i'==1
		replace `j'_allmean=r(mean) if ct`i'==1
		replace `j'_allsd=r(sd) if ct`i'==1
	
		qui sum `j' if year < 1980 & ct`i'==1
		replace `j'_70mean=r(mean) if ct`i'==1
		replace `j'_70sd=r(sd) if ct`i'==1

		qui sum `j' if year < 1990 & year > 1979 & ct`i'==1
		replace `j'_80mean=r(mean) if ct`i'==1
		replace `j'_80sd=r(sd) if ct`i'==1

		qui sum `j' if year < 2000 & year > 1989 & ct`i'==1
		replace `j'_90mean=r(mean) if ct`i'==1
		replace `j'_90sd=r(sd) if ct`i'==1

		qui sum `j' if year > 1999 & year < . & ct`i'==1
		replace `j'_00mean=r(mean) if ct`i'==1
		replace `j'_00sd=r(sd) if ct`i'==1

		local i = `i' + 1
	}
	
	gen `j'_allcv=`j'_allsd/`j'_allmean
	gen `j'_70cv=`j'_70sd/`j'_70mean
	gen `j'_80cv=`j'_80sd/`j'_80mean
	gen `j'_90cv=`j'_90sd/`j'_90mean
	gen `j'_00cv=`j'_00sd/`j'_00mean	
}


	log using T1.log, replace
	
	display "Median of the mean by country"
	display "High Income"
	tabstat not_sdNET_allmean not_sdNET_70mean not_sdNET_80mean not_sdNET_90mean not_sdNET_00mean not_sdTOT_allmean not_sdTOT_70mean not_sdTOT_80mean not_sdTOT_90mean not_sdTOT_00mean not_sdCIF_allmean not_sdCIF_70mean not_sdCIF_80mean not_sdCIF_90mean not_sdCIF_00mean not_sdCOD_allmean not_sdCOD_70mean not_sdCOD_80mean not_sdCOD_90mean not_sdCOD_00mean if HId == 1, stats(median) columns(statistics)
	display "Middle Income"
	tabstat not_sdNET_allmean not_sdNET_70mean not_sdNET_80mean not_sdNET_90mean not_sdNET_00mean not_sdTOT_allmean not_sdTOT_70mean not_sdTOT_80mean not_sdTOT_90mean not_sdTOT_00mean not_sdCIF_allmean not_sdCIF_70mean not_sdCIF_80mean not_sdCIF_90mean not_sdCIF_00mean not_sdCOD_allmean not_sdCOD_70mean not_sdCOD_80mean not_sdCOD_90mean not_sdCOD_00mean if HId == 0 & LMId==0, stats(median) columns(statistics)
	display "Low Income"
	tabstat not_sdNET_allmean not_sdNET_70mean not_sdNET_80mean not_sdNET_90mean not_sdNET_00mean not_sdTOT_allmean not_sdTOT_70mean not_sdTOT_80mean not_sdTOT_90mean not_sdTOT_00mean not_sdCIF_allmean not_sdCIF_70mean not_sdCIF_80mean not_sdCIF_90mean not_sdCIF_00mean not_sdCOD_allmean not_sdCOD_70mean not_sdCOD_80mean not_sdCOD_90mean not_sdCOD_00mean if LMId==1, stats(median) columns(statistics)
	display "All Incomes"
	tabstat not_sdNET_allmean not_sdNET_70mean not_sdNET_80mean not_sdNET_90mean not_sdNET_00mean not_sdTOT_allmean not_sdTOT_70mean not_sdTOT_80mean not_sdTOT_90mean not_sdTOT_00mean not_sdCIF_allmean not_sdCIF_70mean not_sdCIF_80mean not_sdCIF_90mean not_sdCIF_00mean not_sdCOD_allmean not_sdCOD_70mean not_sdCOD_80mean not_sdCOD_90mean not_sdCOD_00mean if HId != . & LMId!=., stats(median) columns(statistics)

	display "Median of the standard deviation by country"
	display "High Income"
	tabstat not_sdNET_allsd not_sdNET_70sd not_sdNET_80sd not_sdNET_90sd not_sdNET_00sd not_sdTOT_allsd not_sdTOT_70sd not_sdTOT_80sd not_sdTOT_90sd not_sdTOT_00sd not_sdCIF_allsd not_sdCIF_70sd not_sdCIF_80sd not_sdCIF_90sd not_sdCIF_00sd not_sdCOD_allsd not_sdCOD_70sd not_sdCOD_80sd not_sdCOD_90sd not_sdCOD_00sd if HId == 1, stats(median) columns(statistics)
	display "Middle Income"
	tabstat not_sdNET_allsd not_sdNET_70sd not_sdNET_80sd not_sdNET_90sd not_sdNET_00sd not_sdTOT_allsd not_sdTOT_70sd not_sdTOT_80sd not_sdTOT_90sd not_sdTOT_00sd not_sdCIF_allsd not_sdCIF_70sd not_sdCIF_80sd not_sdCIF_90sd not_sdCIF_00sd not_sdCOD_allsd not_sdCOD_70sd not_sdCOD_80sd not_sdCOD_90sd not_sdCOD_00sd if HId == 0 & LMId==0, stats(median) columns(statistics)
	display "Low Income"
	tabstat not_sdNET_allsd not_sdNET_70sd not_sdNET_80sd not_sdNET_90sd not_sdNET_00sd not_sdTOT_allsd not_sdTOT_70sd not_sdTOT_80sd not_sdTOT_90sd not_sdTOT_00sd not_sdCIF_allsd not_sdCIF_70sd not_sdCIF_80sd not_sdCIF_90sd not_sdCIF_00sd not_sdCOD_allsd not_sdCOD_70sd not_sdCOD_80sd not_sdCOD_90sd not_sdCOD_00sd if LMId==1, stats(median) columns(statistics)
	display "All Incomes"
	tabstat not_sdNET_allsd not_sdNET_70sd not_sdNET_80sd not_sdNET_90sd not_sdNET_00sd not_sdTOT_allsd not_sdTOT_70sd not_sdTOT_80sd not_sdTOT_90sd not_sdTOT_00sd not_sdCIF_allsd not_sdCIF_70sd not_sdCIF_80sd not_sdCIF_90sd not_sdCIF_00sd not_sdCOD_allsd not_sdCOD_70sd not_sdCOD_80sd not_sdCOD_90sd not_sdCOD_00sd if HId != . & LMId!=., stats(median) columns(statistics)
	
	log close
	
	drop not_sdNET_allmean not_sdNET_70mean not_sdNET_80mean not_sdNET_90mean not_sdNET_00mean not_sdTOT_allmean not_sdTOT_70mean not_sdTOT_80mean not_sdTOT_90mean not_sdTOT_00mean not_sdCIF_allmean not_sdCIF_70mean not_sdCIF_80mean not_sdCIF_90mean not_sdCIF_00mean not_sdCOD_allmean not_sdCOD_70mean not_sdCOD_80mean not_sdCOD_90mean not_sdCOD_00mean  not_sdNET_allsd not_sdNET_70sd not_sdNET_80sd not_sdNET_90sd not_sdNET_00sd not_sdTOT_allsd not_sdTOT_70sd not_sdTOT_80sd not_sdTOT_90sd not_sdTOT_00sd not_sdCIF_allsd not_sdCIF_70sd not_sdCIF_80sd not_sdCIF_90sd not_sdCIF_00sd not_sdCOD_allsd not_sdCOD_70sd not_sdCOD_80sd not_sdCOD_90sd not_sdCOD_00sd 
	
*************
* Table 2
* Correlation between Capital Flows
*************

*BY DECADE
gen decade1=1 if year>=1980 & year<1990
gen decade2=1 if year>=1990 & year<2000
gen decade3=1 if year>=2000 & year<2010
gen decade4=1 if year>=1970 & year<2010 

matrix define Corr=J(10,16,.)

forvalues x=1/4 {
	log using T2.log, replace
	
	xtreg CIF COD `countrydummies' `countrytrenddummies' if HId == 1 & decade`x'==1, fe vce(cluster cnum)
matrix Corr[1,`x']=_b[COD]
matrix Corr[2,`x']=_se[COD]
matrix Corr[3,`x']=tprob(e(df_r),abs(_b[COD]/_se[COD]))
matrix Corr[8,`x']=e(N)
matrix Corr[9,`x']=e(r2)
	qui tab cname if e(sample)
matrix Corr[7,`x']=r(r)
	xtreg COD CIF `countrydummies' `countrytrenddummies' if HId == 1 & decade`x'==1, fe vce(cluster cnum)
matrix Corr[4,`x']=_b[CIF]
matrix Corr[5,`x']=_se[CIF]
matrix Corr[6,`x']=tprob(e(df_r),abs(_b[CIF]/_se[CIF]))
matrix Corr[10,`x']=e(r2)

	xtreg CIF COD `countrydummies' `countrytrenddummies' if HId == 0 & LMId == 0 & decade`x'==1, fe vce(cluster cnum)
matrix Corr[1,4+`x']=_b[COD]
matrix Corr[2,4+`x']=_se[COD]
matrix Corr[3,4+`x']=tprob(e(df_r),abs(_b[COD]/_se[COD]))
matrix Corr[8,4+`x']=e(N)
matrix Corr[9,4+`x']=e(r2)
	qui tab cname if e(sample)
matrix Corr[7,4+`x']=r(r)
	xtreg COD CIF `countrydummies' `countrytrenddummies' if HId == 0 & LMId == 0 & decade`x'==1, fe vce(cluster cnum)
matrix Corr[4,4+`x']=_b[CIF]
matrix Corr[5,4+`x']=_se[CIF]
matrix Corr[6,4+`x']=tprob(e(df_r),abs(_b[CIF]/_se[CIF]))
matrix Corr[10,4+`x']=e(r2)

	xtreg CIF COD `countrydummies' `countrytrenddummies' if LMId == 1 & decade`x'==1, fe vce(cluster cnum)
matrix Corr[1,8+`x']=_b[COD]
matrix Corr[2,8+`x']=_se[COD]
matrix Corr[3,8+`x']=tprob(e(df_r),abs(_b[COD]/_se[COD]))
matrix Corr[8,8+`x']=e(N)
matrix Corr[9,8+`x']=e(r2)
	qui tab cname if e(sample)
matrix Corr[7,8+`x']=r(r)
	xtreg COD CIF `countrydummies' `countrytrenddummies' if LMId == 1 & decade`x'==1, fe vce(cluster cnum)
matrix Corr[4,8+`x']=_b[CIF]
matrix Corr[5,8+`x']=_se[CIF]
matrix Corr[6,8+`x']=tprob(e(df_r),abs(_b[CIF]/_se[CIF]))
matrix Corr[10,8+`x']=e(r2)

	xtreg CIF COD `countrydummies' `countrytrenddummies' if HId != . & LMId != . & decade`x'==1, fe vce(cluster cnum)
matrix Corr[1,12+`x']=_b[COD]
matrix Corr[2,12+`x']=_se[COD]
matrix Corr[3,12+`x']=tprob(e(df_r),abs(_b[COD]/_se[COD]))
matrix Corr[8,12+`x']=e(N)
matrix Corr[9,12+`x']=e(r2)
	qui tab cname if e(sample)
matrix Corr[7,12+`x']=r(r)
	xtreg COD CIF `countrydummies' `countrytrenddummies' if HId != . & LMId != . & decade`x'==1, fe vce(cluster cnum)
matrix Corr[4,12+`x']=_b[CIF]
matrix Corr[5,12+`x']=_se[CIF]
matrix Corr[6,12+`x']=tprob(e(df_r),abs(_b[CIF]/_se[CIF]))
matrix Corr[10,12+`x']=e(r2)

	log close
}

mat2txt, matrix(Corr) saving(T2_Corr) replace

drop decade*

*************
* Table 3
* Cyclicality of Capital Flows 
*************

log using T3.log, replace

local outreg replace
foreach incom in "HId == 1" "HId == 0 & LMId == 0" "LMId == 1" "HId != . & LMId != ." {
foreach YY in TB rgdp_growth {
foreach XX in CIF COD TOT {
	
	xtreg `XX' `YY' `countrydummies' `countrytrenddummies' if `incom', fe vce(cluster cnum)
	outreg2 using T3.out,  excel keep(`YY') bracket  bdec(2) rdec(2) nocons `outreg'
	local outreg append
}
}
}

log close

************
* Table 4
* Capital Flows: Tranquil vs. Crisis Periods - Summary Statistics
************

log using T4.log, replace

display "Crisis Year"
display "High Income"
tabstat not_sdNET not_sdTOT not_sdCIF not_sdCOD if HId == 1 & crisis==1, stats(mean) columns(statistics)
display "Middle Income"
tabstat not_sdNET not_sdTOT not_sdCIF not_sdCOD if HId == 0 & LMId==0 & crisis==1, stats(mean) columns(statistics)
display "Low Income"
tabstat not_sdNET not_sdTOT not_sdCIF not_sdCOD if LMId==1 & crisis==1, stats(mean) columns(statistics)
display "All Incomes"
tabstat not_sdNET not_sdTOT not_sdCIF not_sdCOD if HId != . & LMId!=. & crisis==1, stats(mean) columns(statistics)

	
display "No Crisis Year"
display "High Income"
tabstat not_sdNET not_sdTOT not_sdCIF not_sdCOD if HId == 1 & crisis==0, stats(mean) columns(statistics)
display "Middle Income"
tabstat not_sdNET not_sdTOT not_sdCIF not_sdCOD if HId == 0 & LMId==0 & crisis==0, stats(mean) columns(statistics)
display "Low Income"
tabstat not_sdNET not_sdTOT not_sdCIF not_sdCOD if LMId==1 & crisis==0, stats(mean) columns(statistics)
display "All Incomes"
tabstat not_sdNET not_sdTOT not_sdCIF not_sdCOD if HId != . & LMId!=. & crisis==0, stats(mean) columns(statistics)

log close

quietly foreach j of varlist PIA OIA RES FDIA PIL OIL FDIL PIAe PIAd PILe PILd CIF COD NET TOT TB{
	drop `j'sd
	drop `j'mean
}

quietly foreach j of varlist not_sdCIF not_sdCOD not_sdNET not_sdTOT {
	drop `j'_70cv
	drop `j'_80cv 
	drop `j'_90cv 
	drop `j'_00cv 
	drop `j'_allcv
	drop `j'_70 
	drop `j'_80 
	drop `j'_90 
	drop `j'_00 
}

drop not_sdNET not_sdTOT not_sdCIF not_sdCOD 

*************
* Table 5
*Capital Flows around Crises
*************
gen crisis_orig=crisis

sort cnum year
foreach var in CIF COD PILe PILd OIL FDIL RES PIAe PIAd OIA FDIA  {
gen `var'_orig=`var'
replace `var'=. if crisis==.
}
log using T5.log, replace

foreach incom in "HId != . & LMId != ." {

local outreg replace
foreach XX in CIF FDIL OIL PILd PILe COD FDIA OIA PIAd PIAe RES {

	sort cnum year
	replace crisis=crisis_orig
	replace crisis=0 if crisis==. & ( (`XX'[_n-2]!=. & cname[_n-2]==cname) | (`XX'[_n-1]!=. & cname[_n-1]==cname) | (`XX'[_n+1]!=. & cname[_n+1]==cname) | (`XX'[_n+2]!=. & cname[_n+2]==cname) )

	xtreg `XX' F2.crisis F.crisis crisis L.crisis L2.crisis `countrydummies' `countrytrenddummies' if `incom', fe vce(cluster cnum)
	test (F.crisis + crisis)/2 = F2.crisis
	local one_sidpval_2=ttail(r(df_r),sign(_b[F2.crisis] - 0.5*_b[crisis] - 0.5*_b[F.crisis]) * sqrt(r(F)))
	test crisis = (F2.crisis + F.crisis)/2
	local one_sidpval_6=ttail(r(df_r),sign(0.5*_b[F2.crisis] + 0.5*_b[F.crisis] - _b[crisis]) * sqrt(r(F)))
	test (L.crisis + crisis)/2 = (F2.crisis + F.crisis)/2
	local one_sidpval_8=ttail(r(df_r),sign(0.5*_b[F2.crisis] + 0.5*_b[F.crisis] - 0.5*_b[crisis] - 0.5*_b[L.crisis]) * sqrt(r(F)))
	qui count if crisis==1 & e(sample)
	local number_of_c1= r(N)
	qui tab cname if e(sample)
	local countries = r(r)
	outreg2 using T5.out,  excel keep(F2.crisis F.crisis crisis L.crisis L2.crisis) bracket  bdec(2) rdec(2) nocons adds(No. of Crises,`number_of_c1', No. of Countries,`countries', Avg. T-1/T vs T-2,`one_sidpval_2', T vs Avg. T-1/T-2,`one_sidpval_6', Avg. T/T+1 vs Avg. T-1/T-2,`one_sidpval_8') `outreg'
	local outreg append	
	}
	}
log close

foreach XX in CIF PILe PILd OIL FDIL COD RES PIAe PIAd OIA FDIA crisis{
	replace `XX'=`XX'_orig
}

*************
* Table 6
*Capital Flows around Crises by Income Level
*************
	
log using T6.log, replace

foreach var in CIF COD PILe PILd OIL FDIL RES PIAe PIAd OIA FDIA {
replace `var'=. if crisis==.
}

foreach incom in "HId == 1" "HId == 0 & LMId == 0" "LMId == 1" {

	if "`incom'"=="HId == 1" local inc HI
	if "`incom'"=="HId == 0 & LMId == 0" local inc UMI
	if "`incom'"=="LMId == 1" local inc LMI
			
local outreg replace
foreach XX in CIF FDIL OIL PILd PILe COD FDIA OIA PIAd PIAe RES {

	sort cnum year
	replace crisis=crisis_orig
	replace crisis=0 if crisis==. & ( (`XX'[_n-2]!=. & cname[_n-2]==cname) | (`XX'[_n-1]!=. & cname[_n-1]==cname) | (`XX'[_n+1]!=. & cname[_n+1]==cname) | (`XX'[_n+2]!=. & cname[_n+2]==cname) )

	xtreg `XX' F2.crisis F.crisis crisis L.crisis L2.crisis `countrydummies' `countrytrenddummies' if `incom', fe vce(cluster cnum)
	test (F.crisis + crisis)/2 = F2.crisis
	local one_sidpval_2=ttail(r(df_r),sign(_b[F2.crisis] - 0.5*_b[crisis] - 0.5*_b[F.crisis]) * sqrt(r(F)))
	test crisis = (F2.crisis + F.crisis)/2
	local one_sidpval_6=ttail(r(df_r),sign(0.5*_b[F2.crisis] + 0.5*_b[F.crisis] - _b[crisis]) * sqrt(r(F)))
	test (L.crisis + crisis)/2 = (F2.crisis + F.crisis)/2
	local one_sidpval_8=ttail(r(df_r),sign(0.5*_b[F2.crisis] + 0.5*_b[F.crisis] - 0.5*_b[crisis] - 0.5*_b[L.crisis]) * sqrt(r(F)))
	qui count if crisis==1 & e(sample)
	local number_of_c1= r(N)
	qui tab cname if e(sample)
	local countries = r(r)
	outreg2 using T6`inc'.out,  excel keep(F2.crisis F.crisis crisis L.crisis L2.crisis) bracket  bdec(2) rdec(2) nocons adds(No. of Crises,`number_of_c1', No. of Countries,`countries', Avg. T-1/T vs T-2,`one_sidpval_2', T vs Avg. T-1/T-2,`one_sidpval_6', Avg. T/T+1 vs Avg. T-1/T-2,`one_sidpval_8') `outreg'
	local outreg append
	}
	}
log close

foreach XX in CIF PILe PILd OIL FDIL COD RES PIAe PIAd OIA FDIA crisis{
	replace `XX'=`XX'_orig
}

*************
* Table 7
* Capital Flows around Domestic vs Global Crises
*************
		
	sort cnum year
		
	gen domcri_orig = domcrisis
	gen globcri_orig = globcrisis
	
	log using T7.log, replace

	foreach incom in "HId != . & LMId != ." {

	local outreg replace

	foreach XX in CIF FDIL OIL PILd PILe COD FDIA OIA PIAd PIAe RES {

	replace domcrisis=domcri_orig
	replace globcrisis=globcri_orig

	sort cnum year
	replace `XX'=`XX'_orig
	replace `XX'=. if domcris==. & globcris==.
	
	replace domcris=0 if domcris==. & ( (`XX'[_n-2]!=. & cname[_n-2]==cname) | (`XX'[_n-1]!=. & cname[_n-1]==cname) | (`XX'[_n+1]!=. & cname[_n+1]==cname) | (`XX'[_n+2]!=. & cname[_n+2]==cname) )
	replace globcris=0 if globcris==. & ( (`XX'[_n-2]!=. & cname[_n-2]==cname) | (`XX'[_n-1]!=. & cname[_n-1]==cname) | (`XX'[_n+1]!=. & cname[_n+1]==cname) | (`XX'[_n+2]!=. & cname[_n+2]==cname) )		
	
	xtreg `XX' F2.domcris F.domcris domcris L.domcris L2.domcris F2.globcris F.globcris globcris L.globcris L2.globcris `countrydummies' `countrytrenddummies' if `incom', fe vce(cluster cnum)
	test (F.domcris + domcris)/2 = F2.domcris
	local one_sidpval_2=ttail(r(df_r),sign(_b[F2.domcris] - 0.5*_b[domcris] - 0.5*_b[F.domcris]) * sqrt(r(F)))
	test domcris = (F2.domcris + F.domcris)/2
	local one_sidpval_6=ttail(r(df_r),sign(0.5*_b[F2.domcris] + 0.5*_b[F.domcris] - _b[domcris]) * sqrt(r(F)))
	test (L.domcris + domcris)/2 = (F2.domcris + F.domcris)/2
	local one_sidpval_8=ttail(r(df_r),sign(0.5*_b[F2.domcris] + 0.5*_b[F.domcris] - 0.5*_b[domcris] - 0.5*_b[L.domcris]) * sqrt(r(F)))
	count if domcris==1 & e(sample)
	local number_of_domcri= r(N)
	test (F.globcris + globcris)/2 = F2.globcris
	local one_sidpval_22=ttail(r(df_r),sign(_b[F2.globcris] - 0.5*_b[globcris] - 0.5*_b[F.globcris]) * sqrt(r(F)))
	test globcris = (F2.globcris + F.globcris)/2
	local one_sidpval_62=ttail(r(df_r),sign(0.5*_b[F2.globcris] + 0.5*_b[F.globcris] - _b[globcris]) * sqrt(r(F)))
	test (L.globcris + globcris)/2 = (F2.globcris + F.globcris)/2
	local one_sidpval_82=ttail(r(df_r),sign(0.5*_b[F2.globcris] + 0.5*_b[F.globcris] - 0.5*_b[globcris] - 0.5*_b[L.globcris]) * sqrt(r(F)))
	qui count if globcris==1 & e(sample)
	local number_of_globcri= r(N)
	qui tab cname if e(sample)
	local number_countries = r(r)
	outreg2 using T7.out,  excel keep(F2.domcrisis F.domcrisis domcrisis L.domcrisis L2.domcrisis F2.globcrisis F.globcrisis globcrisis L.globcrisis L2.globcrisis) bracket  bdec(2) rdec(2) nocons adds(No. of Domestic Crises,`number_of_domcri',No. of Global Crises,`number_of_globcri',No. of Countries,`number_countries', /*
	*/ DC: Avg. T-1/T vs T-2,`one_sidpval_2', /*
	*/ DC: T vs Avg. T-1/T-2,`one_sidpval_6', /*
	*/ DC: Avg. T/T+1 vs Avg. T-1/T-2,`one_sidpval_8', /*
	*/ GC: Avg. T-1/T vs T-2,`one_sidpval_22', /*
	*/ GC: T vs Avg. T-1/T-2,`one_sidpval_62', /*
	*/ GC: Avg. T/T+1 vs Avg. T-1/T-2,`one_sidpval_82' /*
	*/  ) `outreg'
	local outreg append
	
	}
	}
log close

	replace domcrisis=domcri_orig
	replace globcrisis=globcri_orig

foreach XX in CIF PILe PILd OIL FDIL COD RES PIAe PIAd OIA FDIA {
	replace `XX'=`XX'_orig
}

*************
* Table 8
*Capital Flows around Banking, Currency, and Debt Crises
*************
	
	gen debtcrisis_orig = debtcrisis
	gen bankcrisis_orig = bankcrisis
	gen currcrisis_orig = currcrisis
		
	foreach cri in bankcrisis currcrisis debtcrisis{

	foreach incom in "HId != . & LMId != ." {

	local outreg replace

	foreach XX in CIF FDIL OIL PILd PILe COD FDIA OIA PIAd PIAe RES {

	sort cnum year
	*Replace crisis as 0 so as to not to loose observations
	*Replace LHS variables with missing when crisis is missing, then replace crisis as 0 so as to not to loose observations
	replace `XX'=`XX'_orig
	replace `cri'=`cri'_orig
	
	replace `XX'=. if `cri'==.
	replace `cri'=0 if `cri'==. & ( (`XX'[_n-2]!=. & cname[_n-2]==cname) | (`XX'[_n-1]!=. & cname[_n-1]==cname) | (`XX'[_n+1]!=. & cname[_n+1]==cname) | (`XX'[_n+2]!=. & cname[_n+2]==cname) )

	
	capture noisily xtreg `XX' F2.`cri' F.`cri' `cri' L.`cri' L2.`cri' `countrydummies' `countrytrenddummies' if `incom', fe vce(cluster cnum)
	capture noisily test (F.`cri' + `cri')/2 = F2.`cri'
	local one_sidpval_2=ttail(r(df_r),sign(_b[F2.`cri'] - 0.5*_b[`cri'] - 0.5*_b[F.`cri']) * sqrt(r(F)))
	capture noisily test `cri' = (F2.`cri' + F.`cri')/2
	local one_sidpval_6=ttail(r(df_r),sign(0.5*_b[F2.`cri'] + 0.5*_b[F.`cri'] - _b[`cri']) * sqrt(r(F)))
	capture noisily test (L.`cri' + `cri')/2 = (F2.`cri' + F.`cri')/2
	local one_sidpval_8=ttail(r(df_r),sign(0.5*_b[F2.`cri'] + 0.5*_b[F.`cri'] - 0.5*_b[`cri'] - 0.5*_b[L.`cri']) * sqrt(r(F)))
	qui count if `cri'==1 & e(sample)
	local number_of_c1= r(N)
	qui tab cname if e(sample)
	local number_countries = r(r)
	outreg2 using T8_`cri'.out, excel keep(F2.`cri' F.`cri' `cri' L.`cri' L2.`cri') bracket  bdec(2) rdec(2) nocons adds(No. of Crises,`number_of_c1', No. of Countries,`number_countries', Avg. T-1/T vs T-2,`one_sidpval_2', T vs Avg. T-1/T-2,`one_sidpval_6', Avg. T/T+1 vs Avg. T-1/T-2,`one_sidpval_8') `outreg'
	local outreg append
	}
	}
	}
	
foreach XX in CIF PILe PILd OIL FDIL COD RES PIAe PIAd OIA FDIA bankcrisis currcrisis debtcrisis{
	replace `XX'=`XX'_orig
}

foreach XX in CIF PILe PILd OIL FDIL COD RES PIAe PIAd OIA FDIA bankcrisis currcrisis debtcrisis crisis{
	drop `XX'_orig
}

drop domcri_orig globcri_orig

cd ..

